@@ -20,7 +20,7 @@ session_start();
 // Set some override for $abook->limit
 // useful for contact pane in adv int
 // and select list in group creation
-$abookLimitOverride = $pref['AbookLimitOverride'];
+$abookLimitOverride = (is_numeric($pref['AbookLimitOverride'])) ? $pref['AbookLimitOverride'] : '99999';
 
 $atmail = new AtmailGlobal();
 
@@ -1306,13 +1306,15 @@ function sort_entry($abook, $key , $h)
 	}
 
 	// Append the FirstName Lastname <email@host>, otherwise use the accounts email-address
-	if (strlen($h[$key]['UserFirstName']) > 0  && strlen($h[$key]['UserLastName']) > 0)
+	if (strlen($h[$key]['UserFirstName']) > 0  || strlen($h[$key]['UserLastName']) > 0)
 	{
 		$full_name = $h[$key]['UserFirstName'].' '.$h[$key]['UserLastName'];
+		$full_name = trim($full_name);
 
-		if (preg_match('/[.]/i', $full_name)) {
-			$full_name = '"'.$full_name.'"';
+		if (substr($full_name, 0, 1) != '"' && substr($full_name, -1) != '"') {
+            $full_name = '"'.$full_name.'"';
 		}
+
 		$username = $full_name.' &lt;'.$email.'&gt;';
 	} else {
 		$username = $email ;
