@@ -874,7 +874,7 @@ class Abook
 	    }
 
 	    // Check file extension
-	    if (!preg_match('/\.(csv|txt)$/', $_FILES['fileupload']['name'])) {
+	    if (!preg_match('/\.(csv|txt)$/i', $_FILES['fileupload']['name'])) {
 	        $this->jsalert = 'csv_import_bad_filetype';
 	        return false;
 	    }
