@@ -412,11 +412,17 @@ class Auth {
 		    return -1;
 		}
 
+		$settings['UseSSL'] = 0;  
+		
 		// Select the MailType - SQL or Flatfile
 	    // All functions are based on what type of account the user has
-	    if ( !$domains[$this->pop3host])
+	    if ( !$domains[$this->pop3host]) {
 	        $settings['MailType'] = $_REQUEST['MailType'];
-
+	        if (strpos($settings['MailType'], 's')) {
+	        	$settings['UseSSL'] = 1;
+	        	$settings['MailType'] = str_replace('s', '', $settings['MailType']);
+	        }
+	    }
 	    elseif ( $pref['sql_type'] && $domains[$this->pop3host])
 	        $settings['MailType'] = 'sql';
 
@@ -529,7 +535,13 @@ class Auth {
 
 		require_once('GetMail.php');
 		//'Username' 'Pop3host' 'Type' 'Mode'
-		$mail = new GetMail(array('Username' => $this->username, 'Pop3host' => $this->pop3host, 'Type' => $settings['MailType'], 'Mode' => 'sql'));
+		$mail = new GetMail(array(
+			'Username' => $this->username, 
+			'Pop3host' => $this->pop3host, 
+			'Type' => $settings['MailType'], 
+			'Mode' => 'sql',
+			'UseSSL' => $settings['UseSSL']));
+
 
 		$mail->login();
 
@@ -706,9 +718,9 @@ class Auth {
 	   $uname = preg_quote($uname);
 
 	   foreach (array_keys($reserved) as $rname) {
-	       $rname = preg_quote($rname, '/');
+	       $rname = preg_quote(trim($rname), '/');
 	       $rname = str_replace('\*', '.*', $rname);
-	       if (preg_match("/$rname/i", $uname))
+	       if (preg_match("/^$rname$/i", $uname))
 	           return true;
 	   }
 
