@@ -166,6 +166,13 @@ class Generic_Mail
 				require_once('Net/POP3.php');
 				$this->mailer = new Net_POP3();
 
+				if ($SSL) {
+					$this->port = 995;
+					$host = "ssl://$host";
+				} else {
+					$this->port = 110;
+				}
+				
 				// set debugging output
 				$this->mailer->setDebug($this->debug);
 
@@ -174,7 +181,7 @@ class Generic_Mail
 				//	$conn = $this->catchDebugging('connect', array($host));
 				//else
 				ob_start();
-				$conn = $this->mailer->connect($host);
+				$conn = $this->mailer->connect($host, $this->port);
 				ob_end_clean();
 	
 				if (!$conn)
@@ -186,19 +193,20 @@ class Generic_Mail
 				require_once('IMAP_Client.php');
 				$this->mailer = new IMAP_Client;
 
+				if ($SSL) {
+					$this->port = 993;	
+				} else {
+					$this->port = 143;
+				}
+				
 				// set debugging output
 				$this->mailer->setDebug($pref['popimap_debug'], $pref['popimap_debug_file'], $pref['popimap_debug_file_size_limit']);
 
-				if (!$this->mailer->connect($host))
+				if (!$this->mailer->connect($host, $this->port, $timeout, $SSL))
 					$this->errors[] = "-ERR Connection to IMAP server failed";
 			}
 		}
 
-		if ($protocol == 'POP3')
-			$this->port = 110;
-		elseif ($protocol == 'IMAP')
-			$this->port = 143;
-
 		$this->protocol = $protocol;
 		$this->host = $host;
 		$this->timeout = $timeout;
