@@ -87,9 +87,9 @@ class GetMail
 
 		// See if the user has defined another MailServer to connect and access the MailAuth type
 		$UserSettings = Filter::cleanSqlFieldNames($this->sql->UserSettings);
-		$query = "select MailServer, MailAuth, DateFormat, TimeFormat, Language, TimeZone from $UserSettings where Account=?";
+		$query = "select MailServer, MailAuth, DateFormat, TimeFormat, Language, TimeZone, UseSSL from $UserSettings where Account=?";
 
-		list($this->MailServer, $this->MailAuth, $this->DateFormat, $this->TimeFormat, $this->Language, $this->TimeZone) = $this->sql->sqlarray($query, $this->Account);
+		list($this->MailServer, $this->MailAuth, $this->DateFormat, $this->TimeFormat, $this->Language, $this->TimeZone, $this->UseSSL) = $this->sql->sqlarray($query, $this->Account);
 
 		$this->MailDir = $this->sql->getvalue("select MailDir from Users where Account=?",$this->Account);
 
@@ -415,15 +415,22 @@ class GetMail
     		// Check if the email equals any of our filters
     		foreach ( array_keys($sort_email) as $sort) {
 
+                $orig = $sort;
     			$this->sortactive = true;
 
-    			if ( preg_match("/From.*?$sort.*?/i", $email['header']) && $this->folderexists($sort_email[$sort], $folders)) {
+    		    // Remove any slashes added when inserted into DB
+    		    $sort = stripslashes($sort);
+
+    		    // Escape any regular expression characters
+                $sort = preg_quote($sort, '/');
+
+    			if ( preg_match("/From:.*?$sort.*?/i", $email['header']) && $this->folderexists($sort_email[$orig], $folders)) {
 
     				$this->msgmove++;
     				$match = true;
-    				$email['UID'] = $this->move( $id, "Inbox", $sort_email[$sort], 0, true);
-    				$email['folder'] = $sort_email[$sort];
-    				$email['Status'] = $atmail->parse("html/$atmail->Language/msg/sortmsgs.html", array('folder' => $sort_email[$sort]));
+    				$email['UID'] = $this->move( $id, "Inbox", $sort_email[$orig], 0, true);
+    				$email['folder'] = $sort_email[$orig];
+    				$email['Status'] = $atmail->parse("html/$atmail->Language/msg/sortmsgs.html", array('folder' => $sort_email[$orig]));
 
     				// Change the message font to bold ( in the stylesheet )
     				$email['msgclass'] = "itemi";
@@ -667,6 +674,90 @@ class GetMail
 		}
 	}
 
+	// buildos_ignore {
+	/**
+	 * Delete a folder in the SQL database, including the messages,
+	 * emailuidl referneces and any sub-folders + messages
+	 *
+	 * Updated to use new SQL functions with placeholders
+	 *
+	 * @param string $folder
+	 */
+	function delfolder_sql($folder)
+	{
+		if (!$folder)
+			return;
+
+		// First remove all messages
+	    $this->purgefolder_sql($folder);
+
+	    // Delete the folder, only if it's not a default folder
+	    if (!$this->isAtmailFolder($folder))
+	    {
+			// First, delete any sub-folders and call the function again()
+			$id = $this->sql->sqlgetfield("SELECT id
+										   FROM Folders
+										   WHERE FolderName = ? AND Account = ?",
+										  array($folder, $this->Account));
+
+			$children = $this->sql->sqlarray("SELECT FolderName
+											  FROM Folders
+											  WHERE ParentID = ? AND Account = ?",
+											 array($id, $this->Account));
+
+			foreach($children as $child)
+			{
+				 if(!$child)
+				 	continue;
+
+				 $this->delfolder($child);
+			 }
+
+			// Remove the folder
+			$this->sql->sqldo("DELETE
+							   FROM Folders
+							   WHERE FolderName = ? AND Account = ?",
+							  array($folder, $this->Account));
+	    }
+	}
+
+
+	function purgefolder_sql($folder)
+	{
+		$ids = $this->sql->sqlarray("SELECT id
+	    							 FROM {$this->sql->EmailDatabase}
+	    							 WHERE EmailBox = ? AND Account = ?",
+	    							array($folder, $this->Account));
+
+		// Cleaup the EmailUIDL table, remove any references to previous messageID's
+		$uidl = $this->sql->sqlarray("SELECT {$this->sql->EmailDatabase}.EmailUIDL
+									  FROM {$this->sql->EmailDatabase}, {$this->sql->EmailUIDL}
+									  WHERE {$this->sql->EmailUIDL}.EmailUIDL = {$this->sql->EmailDatabase}.EmailUIDL
+									  AND {$this->sql->EmailDatabase}.EmailBox = ? AND {$this->sql->EmailDatabase}.Account = ? ",
+									 array($folder, $this->Account));
+
+		// Remove each entry in the EmailUIDL table that matches
+		foreach ($uidl as $v)
+		{
+			$this->sql->sqldo("DELETE
+							   FROM {$this->sql->EmailUIDL}
+							   WHERE EmailUIDL = ? AND Account = ?",
+							  array($v, $this->Account));
+		}
+		// Next, remove any email messages that are marked in the selected folder
+	    foreach ($ids as $id)
+	    {
+	        $this->sql->sqldo("DELETE
+	        				   FROM {$this->sql->EmailDatabase}
+	        				   WHERE id = ? AND Account = ? AND EmailBox = ?",
+	        				  array($id, $this->Account, $folder));
+
+	        $this->sql->sqldo( "DELETE
+	        					FROM {$this->sql->EmailMessage}
+	        					WHERE id = ?", $id );
+		}
+	}
+	// } buildos_ignore
 
 
 	function listfolder_imap($folder=null, $type=null)
@@ -679,46 +770,30 @@ class GetMail
 	    if ( !$this->mailer )
 	        $this->login( $this->Username, $this->Password );
 
-		$tmp = $this->listfolder_sql($folder, $type);
-
-		// Load the folder-list directly from the IMAP server ( no cache )
-		if ((!$pref['imapfolder_cache'] || $_GET['FolderLoad'] == '1') && !isset($_SESSION['ForceImapRefresh'])) {
-			$tmp = $this->mailer->mailboxes($folder, $type);
-		}
+	    // If the script calling the listfolder function is util.php, reload the folder-cache
+        if ((strpos($_SERVER['SCRIPT_NAME'], 'util.php') !== false) && $pref['imapfolder_cache'] )
+        {
+            // Delete the subscribed folder cache
+            $this->delfolder_cache();
+            $tmp = array();
+        }
+	    // Load the folder-list directly from the IMAP server ( no cache )
+        elseif (!$pref['imapfolder_cache'] || $_GET['FolderLoad'] == '1')   {
+            $tmp = $this->mailer->mailboxes($folder, $type);
+        } elseif ($pref['imapfolder_cache']) {
+            $tmp = $this->listfolder_sql($folder, $type);
+        }
 
 		// First time logged into the account
-		elseif ( !count($tmp) && $pref['imapfolder_cache'] )
+		if ( !count($tmp) && $pref['imapfolder_cache'] )
 		{
 			$tmp = $this->mailer->mailboxes($folder, $type);
-			$this->delfolder_cache();
+			//$this->delfolder_cache();
 			// Create each folder in our local cache
 			foreach ($tmp as $v)
 				$this->newfolder_sql($v, '');
 		}
 
-		// If the script calling the listfolder function is util.php, reload the folder-cache
-		elseif ((strpos($_SERVER['SCRIPT_NAME'], 'util.php') !== false || isset($_SESSION['ForceImapRefresh'])) && $pref['imapfolder_cache'] )
-		{
-			// Delete the subscribed folder cache
-			$this->delfolder_cache();
-			
-			// unset this so that future requests in this
-			// session will use the cache
-			if (isset($_SESSION['ForceImapRefresh'])) {
-				unset($_SESSION['ForceImapRefresh']);
-			}
-			
-			// Next, load a list of messages from the remote IMAP server
-			$tmp = $this->mailer->mailboxes($folder, $type);
-
-			if (!$type && is_array($tmp))
-			{
-				// Create each folder in our local cache, mark in the Folders SQL table, Subscribe=1 for local cache
-				foreach ($tmp as $v)
-				    $this->newfolder_sql($v, '');
-			}
-		}
-
 		// Return mailboxes that really exist. Delete folders that are filtered (e.g .folder names)
 		if(is_array($tmp)) {
 		    foreach ($tmp as $v)
@@ -909,6 +984,14 @@ class GetMail
 	{
 		global $atmail;
 
+		if($this->Language == 'espanol')
+		setlocale(LC_TIME, 'es_ES', 'en_US');
+		else if($this->Language == 'italiano')
+		setlocale(LC_TIME, 'it_IT', 'en_US');
+		else if($this->Language == 'russian')
+		setlocale(LC_TIME, 'ru_RU.utf8', 'en_US');
+
+		else if($this->Language != 'japanese' && $this->Language != 'greek' && $this->Language != 'thai')
 		setlocale(LC_TIME, strtolower($this->Language), 'en_US');
 
 		$ctime = array();
@@ -938,14 +1021,38 @@ class GetMail
 
 		if ( $newdate > ( time() - ( ( $minute * 60 ) + ( $hour * 60 * 60 ) ) ) )
 	        $newdate = strftime( $atmail->parse("html/$atmail->Language/msg/today.html") . " $this->TimeFormat", $newdate );
-	    elseif ( $this->Language != "japanese" && $newdate > ( time() - ( 60 * 60 * 24 * 7 ) ) )
+	    elseif ( $this->Language != "japanese" && $newdate > ( time() - ( 60 * 60 * 24 * 7 ) ) ) {
 	        $newdate = strftime( "%a $this->TimeFormat", $newdate);
-	    elseif ( $this->Language == "japanese")
+
+			if($this->Language == 'polish')
+			$newdate = iconv('iso-8859-2', "UTF-8", $newdate);
+			else if($this->Language == 'russian')
+			$newdate = $newdate;
+			else
+			$newdate = iconv('iso-8859-1', "UTF-8", $newdate);
+
+		} elseif ( $this->Language == "japanese") {
 	        $newdate = strftime( "$this->DateFormat %a $this->TimeFormat", $newdate);
-	    else
+
+			if($this->Language == 'polish')
+			$newdate = iconv('iso-8859-2', "UTF-8", $newdate);
+			else if($this->Language == 'russian')
+			$newdate = $newdate;
+			else
+			$newdate = iconv('iso-8859-1', "UTF-8", $newdate);
+
+		} else {
 	        $newdate = strftime( "%a $this->DateFormat $this->TimeFormat", $newdate);
 
-	    $newdate = iconv('iso-8859-1', "UTF-8", $newdate);
+			if($this->Language == 'polish')
+			$newdate = iconv('iso-8859-2', "UTF-8", $newdate);
+			else if($this->Language == 'russian')
+			$newdate = $newdate;
+			else
+			$newdate = iconv('iso-8859-1', "UTF-8", $newdate);
+
+ 		}
+
 	    return $newdate;
 	}
 
@@ -1120,14 +1227,14 @@ class GetMail
 		// Choose which method to authenticate the user
 	    if ( $this->MailServer )
 	    {
-	        $this->mailer = new Generic_Mail($this->MailServer, 'IMAP', 60);
+	        $this->mailer = new Generic_Mail($this->MailServer, 'IMAP', 60, $this->UseSSL);
 			if ($this->mailer->lasterror())
 	        	return false;
 		}
 	    else
 	    {
 	        // Connect to the pop3host the user defined
-	        $this->mailer = new Generic_Mail($this->Pop3host, 'IMAP', 60);
+	        $this->mailer = new Generic_Mail($this->Pop3host, 'IMAP', 60, $this->UseSSL);
 	        if ($this->mailer->lasterror())
 				return false;
 		}
@@ -1213,6 +1320,8 @@ password for the account. Server returned ( $error )";
 	// Delete a mailbox via the IMAP server
 	function delfolder_imap($folder)
 	{
+	    global $pref;
+
 	    // Create the $mail object is not already created
 	    if ( !$this->mailer )
 	    	$this->login();
@@ -1226,11 +1335,14 @@ password for the account. Server returned ( $error )";
 
 	    } elseif( $this->mailer->delete_mailbox($folder) ) {
 			// Find the number of children folders that need to be renamed
-			$children = $this->listfolders($folder);
-
-			foreach($children as $child)
-				$this->mailer->delete_mailbox($child);
+			//$children = $this->mailer->mailboxes($folder, true);
+			//foreach($children as $child)
+				//$this->mailer->delete_mailbox($child);
 
+            // Delete from SQL cache
+            if ($pref['imapfolder_cache']) {
+                $this->delfolder_sql($folder);
+            }
 		}
 
 	    return;
@@ -1261,7 +1373,25 @@ password for the account. Server returned ( $error )";
 	    if ( !$this->mailer )
 			$this->login();
 
-	    $status = $this->mailer->create_mailbox($folder, $subfolder);
+		// we need to break up into individual folders if
+		// a heirarchy has been given
+		if (strpos($folder, $this->Deliminator) && empty($subfolder)) {
+			$folders = explode($this->Deliminator, $folder);
+			$path = '';
+			foreach ($folders as $f) {
+
+				if (empty($path)) {
+					$path = $f;
+				} else {
+					$path .= $this->Deliminator . $f;
+				}
+
+				$status = $this->mailer->create_mailbox($path, '');
+			}
+
+		} else {
+	    	$status = $this->mailer->create_mailbox($folder, $subfolder);
+		}
 
 	    return $status;
 	}
@@ -1339,7 +1469,9 @@ password for the account. Server returned ( $error )";
 			$a = $this->mailer->search($args);
 
 			// Add the additional search elements to the array
-			$msgs = array_merge($msgs, $a);
+			if (is_array($a)) {
+			    $msgs = array_merge($msgs, $a);
+			}
 		}
 
 		return $msgs;
@@ -1551,7 +1683,7 @@ password for the account. Server returned ( $error )";
 	    foreach ($folders as $folder)
 	    {
 			// Skip if the folder matches the current selection, or the Inbox via POP3
-			if ( preg_match("/^$curfolder$/i", $folder) || !$folder
+			if ( (!empty($curfolder) && preg_match("/^$curfolder$/i", $folder)) || !$folder
 	          || $folder == "Inbox" && ( !$domains[$this->Pop3host] && $this->Type == "sql" && $_SERVER['SCRIPT_NAME'] != "search.php" ) || $arr["$folder"] == 1) continue;
 
 	        if ( $pref['imap_subdirectory']
@@ -1632,11 +1764,17 @@ password for the account. Server returned ( $error )";
 			$encoding = $pref['DefaultEncoding'];
 		}
 
+		// Check the encoding is valid, otherwise return without converting
 		if (!$encoding || !$pref['iconv'] || !$data)
 			return $data;
 
-		// Check the encoding is valid, otherwise return without converting
-		$encdata = iconv($encoding, 'utf-8', $data);
+		// Map GB2321 > CP936 - iconv seems to need this to
+		// convert this encoding properly
+		if (strtoupper($encoding) == 'GB2312') {
+		    $encoding = 'CP936';
+		}
+
+		$encdata = iconv($encoding, 'UTF-8', $data);
 
 		if (strlen($encdata) > 0 ) {
 			return $encdata;
@@ -1651,8 +1789,8 @@ password for the account. Server returned ( $error )";
 	{
 		$header = preg_replace('/\s*=\?([^\?]+)\?[Qq]\?([^\?]+)?\?=/e', 'GetMail::decode_language(\'$1\', GetMail::decode_mime_head(\'$1\', \'$2\'))', $header);
 		$header = preg_replace('/\s*=\?([^\?]+)\?[Bb]\?([^\?]+)?\?=/e', 'GetMail::decode_language(\'$1\', base64_decode(\'$2\'))', $header);
-	    $header = preg_replace('/(.+?)<(.*?)>/', '$1&lt;$2&gt;', $header);
-	    $header = str_replace(array('<', '>'), '', $header);
+        $header = preg_replace('/(.+?)<(.*?)>/', '$1&lt;$2&gt;', $header);
+        $header = str_replace(array('<', '>'), '', $header);
 	    $header = trim($header);
 
 		return $header;
@@ -1692,8 +1830,6 @@ password for the account. Server returned ( $error )";
 	}
 
 
-
-
 	function process_headers($headers)
 	{
 		$headers = explode("\n", $headers);
@@ -1765,47 +1901,6 @@ password for the account. Server returned ( $error )";
 	}
 
 
-
-	// Add a new account to the database
-	function addaccount($hash)
-	{
-		if(!$this->sql->sqlgetfield("select Account from Accounts where UserAccount = ? and Account = ?", array("{$hash['Username']}@{$hash['Pop3host']}", "$this->Username@$this->Pop3host")))
-		{
-			// Add the entry into the users Account table
-			$this->sql->sqldo("INSERT INTO Accounts (UserAccount, MailServer, Type, Account) VALUES( ?, ?, ?, ? )",  array( "{$hash['Username']}@{$hash['Pop3host']}", $hash['MailServer'], $hash['MailType'], "$this->Username@$this->Pop3host"));
-
-			// Add the entry into the users Account table
-			$this->sql->sqldo("INSERT INTO Accounts (UserAccount, MailServer, Type, Account) VALUES( ?, ?, ?, ? )", array("$this->Username@$this->Pop3host", $this->MailServer, $this->Type, "{$hash['Username']}@{$hash['Pop3host']}"));
-		}
-
-	    return;
-	}
-
-	// Show the active users for your external accounts
-	function showaccounts($type=null)
-	{
-	    $account = $this->sql->quote($this->Account);
-
-	    if (!$type)
-		{
-			return $this->sql->sqlarray("select concat(UserAccount, ':', MailServer, ':', Type) from Accounts where Type != 'pers' and Account = $account");
-	    }
-	    elseif ($type == 'personalities')
-	       return $this->sql->sqlarray("select UserAccount from Accounts where Account=$account and Type = 'pers'");
-
-		return $this->sql->getvalue("select Password from UserSession where Account = ?", array($type));
-	}
-
-	// Delete a user account
-	function delaccounts($acct, $type=null)
-	{
-		$acct = $this->sql->quote($acct);
-		if ($type == 'personality')
-            $this->sql->sqldo("delete from Accounts where (UserAccount=$acct or Account=$acct) and Type = 'pers'");
-        else
-            $this->sql->sqldo("delete from Accounts where UserAccount=$acct or Account = $acct");
-	}
-
 	function bodyclean($bound, $msg)
 	{
 	    // Escape the EmailBoundary. Just in case.
@@ -2493,7 +2588,6 @@ password for the account. Server returned ( $error )";
 
 		}
 
-
 		return $newdate;
 	}
 
@@ -2569,7 +2663,7 @@ password for the account. Server returned ( $error )";
 		$this->sql->sqldo("DELETE
 						   FROM Folders
 						   WHERE Subscribe = '1' AND Account = ?",
-						  array($this>Account));
+						  array($this->Account));
 		return;
 	}
 
