@@ -61,6 +61,12 @@ function auth($mailauth=null)
     $pop3host = strtolower($_REQUEST['pop3host']);
     $pop3host = trim(str_replace("'", '', $pop3host));
 
+    if ((isset($_REQUEST['UseSSL']) && $_REQUEST['UseSSL'] == 1) || strpos($_REQUEST['MailType'], 's')) {
+        $this->UseSSL = 1;
+    } else {
+        $this->UseSSL = 0;
+    }
+
 	// Lowercase the username
 	$username = strtolower($_REQUEST['username']);
 
@@ -163,8 +169,8 @@ function auth($mailauth=null)
 	    $status = 0;
 
 	    // get mail type
-	    $type = (isset($_REQUEST['MailType']) && strlen($_REQUEST['MailType']) > 0)? $_REQUEST['MailType'] : 'imap';
-	    $type = str_replace("'", '', $type);
+	    $type = (isset($_REQUEST['MailType']) && strlen($_REQUEST['MailType']) > 0)? $_REQUEST['MailType'] : 'pop3';
+	    $type = str_replace('s', '', $type);
 
 	    // If the user selects a different mailserver on the login page
 	    // First try Webadmin > Config > Mailserver field, otherwise MailServer on the login page, otherwise the users domain
@@ -182,7 +188,7 @@ function auth($mailauth=null)
 		// The user account is not local, try and auth via POP3/IMAP
         if ( $type == 'pop3' || $type == 'imap')
 		{
-            $mail = new Generic_Mail($server, $type, 60);
+            $mail = new Generic_Mail($server, $type, 60, $this->UseSSL);
             $status = $mail->lasterror();
         }
 
@@ -363,6 +369,12 @@ function loadprefs()
 		
 	// LeaveMsgs = 0 is not spported as yet
 	$this->LeaveMsgs = 1;
+	
+    if ((isset($_REQUEST['UseSSL']) && $_REQUEST['UseSSL'] == 1) || strpos($_REQUEST['MailType'], 's')) {
+        $this->UseSSL = 1;
+    } else {
+        $this->UseSSL = 0;
+    }
 }
 
 
@@ -545,18 +557,24 @@ function logintype()
 	else
 		$ajax = 0;
 
+	if ((isset($_REQUEST['UseSSL']) && $_REQUEST['UseSSL'] == 1) || strpos($_REQUEST['MailType'], 's')) {
+		$this->UseSSL = 1;
+	} else {
+	    $this->UseSSL = 0;
+	}
+
     // First check if another Language is specified
     if ($this->isset_chk($_REQUEST['Language']))
 	{
-		$query = 'UPDATE '.$this->db->get('UserSettings').' SET LoginType = ?, Language	= ?, Ajax = ? WHERE Account = ?';
-		$data  = array($logintype, $_REQUEST['Language'], $ajax, $this->auth->get_account());
+		$query = 'UPDATE '.$this->db->get('UserSettings').' SET LoginType = ?, Language	= ?, Ajax = ?, UseSSL = ? WHERE Account = ?';
+		$data  = array($logintype, $_REQUEST['Language'], $ajax, $this->UseSSL, $this->auth->get_account());
 
       	$this->db->sqldo($query, $data);
     }
     else
 	{
-        $query = 'UPDATE '.$this->db->UserSettings.' SET LoginType = ?, Ajax = ? WHERE Account = ?';
-		$data  = array($logintype, $ajax, $this->auth->get_account());
+        $query = 'UPDATE '.$this->db->UserSettings.' SET LoginType = ?, Ajax = ?, UseSSL = ? WHERE Account = ?';
+		$data  = array($logintype, $ajax, $this->UseSSL, $this->auth->get_account());
 
         $res = $this->db->sqldo($query, $data);
 
@@ -584,6 +602,13 @@ function mailtype()
 
         $type = $_REQUEST['MailType'] ? $_REQUEST['MailType'] : 'pop3';     // Toggle POP or IMAP
     }
+
+    if ((isset($_REQUEST['UseSSL']) && $_REQUEST['UseSSL'] == 1) || strpos($_REQUEST['MailType'], 's')) {
+        $this->UseSSL = 1;
+        $type = str_replace('s', '', $_REQUEST['MailType']);
+    } else {
+        $this->UseSSL = 0;
+    }
     
     $server = ($pref['mailserver']) ? $pref['mailserver'] : $_REQUEST['MailServer'];
 
@@ -1060,7 +1085,7 @@ function getsort($type, $format=null)
             $h[$v[$type]] = $v['EmailFolder'];
         else
             // Build the select box
-            $tmp .= "<option value=\"$v[$type]\">$v[$type] -&gt; {$v['EmailFolder']}</option>";
+            $tmp .= "<option value=\"" . base64_encode($v[$type]) . "\">" . htmlentities($v[$type]) . " -&gt; {$v['EmailFolder']}</option>";
 
     }
 
@@ -1087,11 +1112,11 @@ function domainbox($domain=null, $type='local')
 	if ($type == 'local') {
 		global $domains;
 	    $tmp = '';
-	
+
 	    if (count($domains) > 0) {
 	        ksort($domains);
 	    }
-	
+
 	    foreach ( array_keys($domains) as $k )
 	    {
 	    	if ($domain && $k == $domain)
@@ -1099,27 +1124,27 @@ function domainbox($domain=null, $type='local')
 	        else
 	        	$tmp .= "<option value='$k'>$k</option>\n";
 	    }
-	
+
 	    return $tmp;
-	    
+
 	} else {
-	
+
 		global $pref;
-		
+
 		$list = '';
-		
+
 		$doms = explode(',', $pref['allowed_domains']);
 		sort($doms);
 		foreach ($doms as $dom) {
 			$dom = trim($dom);
-			
+
 			if (empty($dom)) {
 				continue;
 			}
-			
+
 			$list .= "<option value='$dom'>$dom</option>\n";
 		}
-		
+
 		return $list;
 	}
 }
@@ -1128,21 +1153,21 @@ function domainbox($domain=null, $type='local')
 function mailserverbox()
 {
 	global $pref;
-	
+
 	$list = '';
-		
+
 	$servers = explode(',', $pref['allowed_mailservers']);
 	sort($servers);
 	foreach ($servers as $server) {
 		$server = trim($server);
-		
+
 		if (empty($server)) {
 			continue;
 		}
-		
+
 		$list .= "<option value='$server'>$server</option>\n";
 	}
-	
+
 	return $list;
 }
 
@@ -1181,7 +1206,7 @@ function auth_error()
 		print $this->parse($path, $var);
     	exit;
 	}
-	
+
     if ($pref['opensource']) {
     	header('Location:index.php?error=auth');
     	exit;
@@ -1328,15 +1353,35 @@ function print_mailtypes()
 
     $type = htmlentities($_REQUEST['MailType']);
 
-    if ( $pref['mail_type'] == "pop3" )
-        $select = "<input type='hidden' name='MailType' value='pop3'>";
-    elseif ( $pref['mail_type'] == "imap" )
-        $select = "<input type='hidden' name='MailType' value='imap'>";
-    else
-	{
-		// Select IMAP as the default interface
-        $select = "<select name='MailType'><option value='imap'>IMAP</option><option value='pop3'>POP3</option></select>";
-        str_replace("value='$type'", "value='$type' selected", $select);
+    if ( $pref['mail_type'] == 'pop3') {
+        if ($pref['mail_type_ssl'] == 'deny') {
+            $select = "<input type='hidden' name='MailType' value='pop3'>";
+        } elseif ($pref['mail_type_ssl'] == 'force') {
+            $select = "<input type='hidden' name='MailType' value='pop3s'>";
+        } elseif ($pref['mail_type_ssl'] == 'allow') {
+            $select = "<select name='MailType'><option value='pop3'>POP3</option><option value='pop3s'>POP3 Secure</option></select>";
+            $select = str_replace("value='$type'", "value='$type' selected", $select);
+        }
+    } elseif ( $pref['mail_type'] == 'imap') {
+        if ($pref['mail_type_ssl'] == 'deny') {
+            $select = "<input type='hidden' name='MailType' value='imap'>";
+        } elseif ($pref['mail_type_ssl'] == 'force') {
+            $select = "<input type='hidden' name='MailType' value='imaps'>";
+        } elseif ($pref['mail_type_ssl'] == 'allow') {
+            $select = "<select name='MailType'><option value='imap'>IMAP</option><option value='imaps'>IMAP Secure</option></select>";
+            $select = str_replace("value='$type'", "value='$type' selected", $select);
+        }
+    } elseif ( $pref['mail_type'] == 'pop3imap') {
+        if ($pref['mail_type_ssl'] == 'deny') {
+            $select = "<select name='MailType'><option value='imap'>IMAP</option><option value='pop3'>POP3</option></select>";
+            $select = str_replace("value='$type'", "value='$type' selected", $select);
+        } elseif ($pref['mail_type_ssl'] == 'force') {
+            $select = "<select name='MailType'><option value='imaps'>IMAP Secure</option><option value='pop3s'>POP3 Secure</option></select>";
+        $select = str_replace("value='$type'", "value='$type' selected", $select);
+        } elseif ($pref['mail_type_ssl'] == 'allow') {
+            $select = "<select name='MailType'><option value='imap' >IMAP</option><option value='imaps'>IMAP Secure</option><option value='pop3'>POP3</option><option value='pop3s'>POP3 Secure</option></select>";
+            $select = str_replace("value='$type'", "value='$type' selected", $select);
+        }
     }
 
     return $select;
@@ -1721,7 +1766,7 @@ function escape_pathname($path)
 // Check the users login type
 function checklogintype($value)
 {
-	
+
 	// If using the Advanced interface, switch the template to XUL for FF
 	if (strpos(strtolower($_SERVER['HTTP_USER_AGENT']), 'gecko') !== false && $value == 'xp')
 	$value = "xul";
@@ -1839,9 +1884,9 @@ function generatepermissions($user, $db, $field, $accounts)
 
  				if(!$value)
 				$value = $this->db->getvalue("select CONCAT(Account, ':', id, ':', Permissions) from $db where Account=$account");
-				
+
 				$permissions .= $value . ",";
-				
+
 				//file_put_contents("php://stderr", "PERMS = $permissions\n");
     		}
     		else
