@@ -40,10 +40,15 @@ class PluginHandler
 	}
 	
 	
-	function triggerEvent($event, $args)
+	function triggerEvent($event, &$args)
 	{	
 		foreach ($this->plugins as $plugin) {
-			$plugin->$event($args);
+		    if (method_exists($plugin, $event)) {
+			    $plugin->$event($args);
+			    $args['caught'] = true;
+		    } else {
+		        $args['caught'] = false;
+		    }
 		}
 	}
 	
