@@ -53,14 +53,8 @@ class ReadMsg
 		// exist or we are on a windows box
 		global $pref;
 		if ($pref['decode_tnef']) {
-			if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
+			if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN' || !is_executable($pref['tnef_path'])) {
 				$pref['decode_tnef'] = false;
-			} else {
-
-				$out = `tnef --version 2>&1`;
-				if (!preg_match('/^tnef (\d)/', $out)) {
-					$pref['decode_tnef'] = false;
-				}
 			}
 		}
 	}
@@ -394,7 +388,8 @@ class ReadMsg
 	        	{
 					$line = $this->mail->decode_language($this->Charset, $line);
 	                $line = $atmail->escape_jscript($line);   // Check jscript attacks
-					//$line = $this->scanpgp($line);
+					$line = $this->scanpgp($line);
+					$line = htmlentities($line, ENT_COMPAT, 'UTF-8');
 	                $line = $this->quoteurl($line);
 
 					// Optional filter for censored words
@@ -416,9 +411,9 @@ class ReadMsg
 				// Use the tnef program to decode the attachment
 				$myfiles = array();
 				$mypath = escapeshellarg($part->get_path());
-				exec("tnef -t $mypath", $myfiles);
+				exec("{$pref['tnef_path']} -t $mypath", $myfiles);
 				$save = escapeshellarg($this->tmpdir);
-				system("tnef --overwrite -C $save -f " . $part->get_path());
+				system("{$pref['tnef_path']} --overwrite -C $save -f " . $part->get_path());
 
 				if (is_array($myfiles)) {
 					foreach ($myfiles as $f) {
@@ -431,7 +426,7 @@ class ReadMsg
 						$filename = str_replace(array('/', '\\'), '', $f);
 
 			            // Escape the filename, just in case it contains special characters
-			            $encfilename = urlencode($filename);
+			            $encfilename = rawurlencode($filename);
 
 			            $this->attachname[$filename]['type'] = "file";
 			            $this->attachname[$filename]['size'] = $size;
@@ -494,7 +489,9 @@ class ReadMsg
 						$line = $this->mail->decode_language($this->Charset, $line);
 						if(isset($atmail))
                         $line = $atmail->escape_jscript($line);   // Check jscript attacks
+
 						//$line = $this->scanpgp($line);
+						$line = htmlentities($line, ENT_COMPAT, 'UTF-8');
                         $line = $this->quoteurl($line);
 
 						// Check from HTML tags - if exist, don't <BR> \n characters
@@ -522,7 +519,7 @@ class ReadMsg
 	            $size = $size / 1024;
 	            $size = preg_replace('/(\.\d)\d+/', '$1', $size);
 
-				$filename = $this->myescape($filename);
+	            $filename = rawurlencode($filename);
 				$this->inline[$cid] = "mime.php?file=$filename&cid=$cid";
 				$this->inlinepics = 1;
 
@@ -552,7 +549,7 @@ class ReadMsg
 	            $size = preg_replace('/(\.\d)\d+/', '$1', $size);
 
 	            // Escape the filename, just in case it contains special characters
-	            $filename = urlencode($filename);
+	            $filename = rawurlencode($filename);
 
 	            $this->attachname[$filename]['type'] = "pic";
 	            $this->attachname[$filename]['size'] = $size;
@@ -580,7 +577,7 @@ class ReadMsg
 				$filename = str_replace(array('/', '\\'), '', $filename);
 
 	            // Escape the filename, just in case it contains special characters
-	            $encfilename = urlencode($filename);
+	            $encfilename = rawurlencode($filename);
 
 	            $this->attachname[$filename]['type'] = "file";
 	            $this->attachname[$filename]['size'] = $size;
@@ -957,4 +954,4 @@ _EOF;
 	}
 
 } // end ReagMsg
-?>
\ No newline at end of file
+?>
