@@ -221,7 +221,7 @@ class SendMsg
 			}
 
 			// Only add the footer message if it is not already at bottom of email
-			if (strpos($this->EmailMessage, $pref['footer_msg']) !== strlen($this->EmailMessage) - strlen($pref['footer_msg'])) {
+			if (!empty($pref['footer_msg']) && strpos($this->EmailMessage, $pref['footer_msg']) !== strlen($this->EmailMessage) - strlen($pref['footer_msg'])) {
 				$this->EmailMessage .= "\r\n{$pref['footer_msg']}";
 			}
 	    }
@@ -250,7 +250,7 @@ class SendMsg
 			$pref['footer_msg'] = str_replace("\r", '', $pref['footer_msg']);
 
 
-			if (strpos($this->EmailMessage, $pref['footer_msg']) !== strlen($this->EmailMessage) - strlen($pref['footer_msg'])) {
+			if (!empty($pref['footer_msg']) && strpos($this->EmailMessage, $pref['footer_msg']) !== strlen($this->EmailMessage) - strlen($pref['footer_msg'])) {
 				$this->EmailMessage .= "<BR>{$pref['footer_msg']}";
 			}
 
@@ -333,8 +333,10 @@ EOF;
 
 		        // Optionally encode the users name in the header
 		        preg_match_all('/(?<=")(.+?)(?=" <)/', $this->$type, $m, PREG_SET_ORDER);
-		        foreach ($m[0] as $match) {
-		            $this->$type = str_replace($match, $this->encodeUTF8($match), $this->$type);
+		        if (is_array($m[0])) {
+		        	foreach ($m[0] as $match) {
+		        		$this->$type = str_replace($match, $this->encodeUTF8($match), $this->$type);
+		        	}
 		        }
 		        //$this->$type = preg_replace('/(?<=")(.+?)(?=" <)/e', '$this->encodeUTF8(\'$1\')', $this->$type);
 
