@@ -29,40 +29,46 @@ class IMAP_Client
 
 	/**
 	 * The socket connection
-	 * @param Net_Socket
+	 * @var Net_Socket
 	 */
 	var $socket;
 
 	/**
 	 * The hierarchy delimiter
-	 * @param string
+	 * @var string
 	 */
 	var $delimiter;
 
 	/**
 	 * The command ID
-	 * @param int
+	 * @var int
 	 */
 	var $cid = 'ATMAIL00';
 
 	/**
 	 * Debug flag
-	 * @param bool
+	 * @var bool
 	 */
 	var $debug = false;
 
 	/**
 	 * Are we logged in?
-	 * @param bool
+	 * @var bool
 	 */
 	 var $loggedIn = false;
 
 	 /**
 	  * IMAP server's capabilities
-	  * @param array
+	  * @var array
 	  */
 	 var $capabilities;
 
+	 /**
+	  * Are we sing SSL?
+	  * @var bool
+	  */
+	 var $SSL = false;
+
 
 	/**
 	 * Constructor
@@ -88,13 +94,17 @@ class IMAP_Client
 	 * @param int $port
 	 * @param int $timeout
 	 */
-	function connect($host = 'localhost', $port = 143, $timeout=30)
+	function connect($host = 'localhost', $port = 143, $timeout=30, $ssl=false)
 	{
 		$this->host = $host;
 
+		if ($ssl) {
+			$host = "ssl://$host";
+			$this->SSL = true;
+		}
+
 		$con = $this->socket->connect($host, $port, null, $timeout);
-		if (PEAR::isError($con))
-		{
+		if (PEAR::isError($con)) {
 			return false;
 		}
 
@@ -103,12 +113,9 @@ class IMAP_Client
 		if (substr($resp, 0, 4) != '* OK')
 			return false;
 
-		if (preg_match('/\[CAPABILITY (.+?)\]/i', $resp, $m))
-		{
+		if (preg_match('/\[CAPABILITY (.+?)\]/i', $resp, $m)) {
 			$this->capabilities = explode(' ', $m[1]);
-		}
-		else
-		{
+		} else {
 			$resp = $this->capability();
 
 			if (is_array($resp))
@@ -316,7 +323,7 @@ class IMAP_Client
 				// If no UID we should skip as email cannot be opened
 				//continue;
 			}
-			
+
 			$EmailMsg = substr($info, -255);
 			$EmailMsg = preg_replace('/BODY.*?\s/im', '', $EmailMsg);
 			$EmailMsg = preg_replace('/\)/', '', $EmailMsg);
@@ -884,8 +891,8 @@ class IMAP_Client
 
 		}
 
-		return $this->sendCmd("UNSUBSCRIBE \"$delmailbox\"");
-
+		$resp = $this->sendCmd("UNSUBSCRIBE \"$delmailbox\"");
+        return ($resp !== false);
 	}
 
 
@@ -1236,7 +1243,7 @@ class IMAP_Client
 			elseif (is_resource($fh))	{
 
 				$bytesRead += strlen($line);
-				
+
 				// Strip Control-M chars
 				$line = preg_replace('/\cM+$/', '', $line);
 
