@@ -40,11 +40,6 @@ $atmail->httpheaders();
 // Load the account preferences
 $atmail->loadprefs();
 
-if ($pref['mailos']) {
-	require_once('MailOS.php');
-	$mailos = new MailOS(array('Account' => $atmail->Account));
-}
-
 // Parse the users custom stylesheet
 
 $var['atmailstyle'] = $atmail->parse("html/$atmail->Language/$atmail->LoginType/atmailstyle.css" );
@@ -153,16 +148,15 @@ elseif ( $msgs && $var['newfolder'] )
 		if (strpos($id, '::') !== false)
 		{
 			$tmp = explode('::', $id);
-			$var['folder'] = $tmp[1];
+			//$var['folder'] = $tmp[1];
 			$arr[0] = $tmp[0];
-			$arr[1] = $tmp[2];
+			//$arr[1] = $tmp[2];
 		}
 		else
 			$arr = explode(":", $id);
 
 		$cnt++;
 
-
 		if($arr[1] && !$count)
 		{
 			// Move the selected message, but first check the sequence number/uidl matches the message header
@@ -185,6 +179,7 @@ elseif ( $msgs && $var['newfolder'] )
 	// If this is an Ajax call, print the header, then exit
 	if ($atmail->Ajax && $var['newfolder'] )
 	{
+		$var['folder'] = str_replace('&', '&amp;', $var['folder']);
 		print <<<EOF
 <?xml version="1.0" ?>
 <MovedMsgs>
@@ -201,6 +196,7 @@ EOF;
 	// If this is an Ajax call, print the header, then exit
 	if ($atmail->Ajax)
 	{
+		$var['folder'] = str_replace('&', '&amp;', $var['folder']);
 		echo <<<_EOF
 <?xml version="1.0" ?>
 
@@ -270,6 +266,7 @@ _EOF;
 				$counter = str_replace(array('(', ')'), '', $counter);
 				$var['folders_default_ajax'] .= <<<_EOF
 <Fol Name="$fol" Display="$foldertranslate" Count="$counter" Icon="$icon" State=""></Fol>
+
 _EOF;
 
 			}
@@ -305,6 +302,7 @@ _EOF;
 				$icon = strtolower($fol);
 				$var['folders_default_ajax'] .= <<<_EOF
 <Fol Name="$fol" Display="$foldertranslate" Count="" Icon="$icon" State=""></Fol>
+
 _EOF;
 			}
 		}
@@ -312,6 +310,7 @@ _EOF;
 
 	$var['folders_default_ajax'] .= <<<EOF
 <Fol Name="erase" Display="Erase" Count="" Icon="erase" State=""></Fol>
+
 EOF;
 
 	foreach ($folders as $folder)
@@ -351,8 +350,10 @@ EOF;
 
 		if ($atmail->Ajax)
 		{
+		$folder = str_replace('&', '&amp;', $folder);
 			$var['folders_default_ajax'] .= <<<EOF
 <Fol Name="$folder" Display="$folder" Count="" Icon="folder" State=""></Fol>
+
 EOF;
 		}
 		else
@@ -658,23 +659,28 @@ if ($var['msg_pos'] == 1)
 if ($var['prev'])
 	$var['msg_pos']++;
 
-if ($_REQUEST['start'])
-	$start = $total - $atmail->MsgNum - $_REQUEST['start'];
-else
-{
+if ($_REQUEST['start']) {
+	$start = $total - $_REQUEST['start'] - $atmail->MsgNum;
+} else {
 	if ($total < $atmail->MsgNum)
 		$start = 0;
 	else
 		$start = $total - $atmail->MsgNum;
 }
+
 if ($total < $atmail->MsgNum)
 	$end = $total;
 else
-	$end = $start + $atmail->MsgNum;
+	$end = $start + $atmail->MsgNum - 1;
 
 if ($start < 0)
 	$start = 0;
 
+if ($end < $total)
+    $end++;
+
+$start++;
+
 
 $emails = $mail->getmailboxsummary($start, $end, $var['folder']);
 
